# -*- coding: utf-8 -*-
# vim:fenc=utf-8
#
# Copyright (C) 2014 Xavier Bruhiere
# Distributed under terms of the MIT license.

import os
import sh


def clean_wercker(target):
    ''' Remove wercker specific stuff '''
    sh.rm('-r', os.path.join(target, 'source/articles'))

    data_path = os.path.join(target, 'data')
    if not os.path.exists(data_path):
        sh.mkdir(data_path)


def _walk_source(path, dirname, fnames):
    if 'articles' in fnames:
        path.append(dirname)


def check_source(source):
    if source.find('github') > 0:
        default_target = '/tmp/doc'
        print('cloning data source to {}'.format(default_target))
        clone(source, default_target)

        # Search for the documentatino directory
        data_path = ['/tmp']
        os.path.walk(default_target, _walk_source, data_path)
        data_path = '/'.join(data_path)
    else:
        data_path = source

    assert os.path.exists(data_path)
    return data_path


def copy_data(source, target):
    '''
    Copy doc files and configuration to the middleman project
    '''
    sh.cp(os.path.join(source, 'project.yml'),
          os.path.join(target, 'data'))

    #TODO Patch this file to add the author html
    sh.cp(os.path.join(source, 'index.html.md'),
          os.path.join(target, 'source/index.html.md'))

    #TODO Walk the files tree to add footers and headers
    sh.cp('-r', os.path.join(source, 'articles'),
          os.path.join(target, 'source/articles'))

    if os.path.exists('{}/images'.format(source)):
        sh.cp(os.path.join(source, 'images/*'),
              os.path.join(target, 'source/images'))


def clone(git_url, target_path):
    if not os.path.exists(target_path):
        print('cloning backbone repository: {} to {}'
              .format(git_url, target_path))
        sh.git("clone", git_url, target_path, depth=1, branch='master')
