# -*- coding: utf-8 -*-
# vim:fenc=utf-8

'''okdoc

Usage:
    okdoc (-h | --help)
    okdoc (-v | --version)
    okdoc new -t=<title | --title=<title>
    okdoc build --from=<dir> [--to=<dir>] [--backbone=<repo>]

Options:
  -h --help           Show this screen.
  -v --version        Show version.
  -t --title=<title>  New article title
  --from=<dir>        okdoc ready documentation root path
  --to=<dir>          path of the new website [default: doc]
  --backbone=<repo>   backbone github repo [default: wercker/wercker-devcenter]
'''

import sys
import os
import datetime as dt
from docopt import docopt
import okdoc.layout as layout
import okdoc.backbone as backbone


def build_doc(from_path, to_path, gh_backbone='wercker/wercker-devcenter'):
    # Clone the backbone repository
    backbone_url = 'https://github.com/{}.git'.format(gh_backbone)
    backbone.clone(backbone_url, to_path)

    print('cleaning unnecessary files')
    backbone.clean_wercker(to_path)

    print('inspecting data source')
    from_path = backbone.check_source(from_path)
    print('copying documentation data')
    backbone.copy_data(from_path, to_path)

    print('building layout...')
    layout.build(to_path)

    print '\nYour documentation code is ready:'
    print '\t$ cd %s' % to_path
    print '\t$ # Remove .ruby-version, or install ruby 2.0.0-p247'
    print '\t$ bundle install'
    print '\t$ bundle exec middleman build'
    print '\t$ bundle exec middleman server'
    print '\t$ # This is even ready for heroku\n'


def create_new_article(title):
    # TODO Handle index.html.md
    # TODO Make sure lower() and '_'
    print 'registering content'
    current_directory = os.getcwd().split('/')[-1]
    if title != 'index':
        sidebar = '-'.join([current_directory, title])
    else:
        sidebar = current_directory

    completion = {
        'article': {
            'title': title,
            'sidebar_title': sidebar,
            'creation_date': str(dt.date.today())
        }
    }

    print 'generating article'
    layout.generate(
        completion,
        templates_path=os.path.expanduser('~/.okdoc'),
        template='article.tpl',
        target=title+'.md')


def okdoc(args):
    if args['build']:
        build_doc(args['--from'], args['--to'], args['--backbone'])
    elif args['new']:
        create_new_article(args['--title'])
    else:
        print 'what ?'


def main():
    args = docopt(__doc__, version='okdoc v0.0.3')
    #try:
    okdoc(args)
    code = 0
    #except Exception, error:
    #print error
    #code = 1

    return code

if __name__ == '__main__':
    sys.exit(main())
